@@ -104,9 +104,9 @@ class Lazuli:
             Defaults to None if the operation fails.
 
         Raises:
-            Generic error on failure - handled by the Character::get_db() method
+            Generic error on failure - handled by the utility.get_db_first_hit() method
         """
-        character_stats = Character.get_db_first_hit(
+        character_stats = utils.get_db_first_hit(
             self._database_config,
             f"SELECT * FROM characters WHERE `name` = '{char_name}'"
         )  # Fetch first result because there should only be one character with that name
@@ -128,9 +128,9 @@ class Lazuli:
             Account object with attributes identical to its corresponding entry in the database
 
         Raises:
-            Generic error on failure - handled by the Character::get_db() method
+            Generic error on failure - handled by the utility.get_db_first_hit() method
         """
-        account_info = Character.get_db_first_hit(
+        account_info = utils.get_db_first_hit(
             self._database_config,
             f"SELECT * FROM accounts WHERE `name` = '{username}'"
         )  # Fetch first result because there should only be one character with that name
@@ -232,57 +232,95 @@ class Lazuli:
         player_data = self.get_online_list()
         return utils.extract_name(player_data)
 
-    def get_level_ranking(self):
-        """Fetches the Top 5 players in terms of level
+    def get_level_ranking(self, number_of_players=5, show_gm=False):
+        """Fetches the top ranking players in terms of level
 
-        Uses Lazuli::get_db_all_hits to query, and utility.extract_name to process the data.
+        Uses Lazuli::get_db_all_hits to query, and utility.extract_name_and_value to process the data.
+
+        Args:
+            show_gm: (optional): Add GMs (Game Masters) to the list of rankings
+            number_of_players (optional): Int, e.g. Top 5 Ranking (default), Top 10 Ranking, etc.
 
         Returns:
-            List of Strings, representing player names
+            List of Tuples, representing player names and their corresponding level
         """
-        player_data = self.get_db_all_hits("SELECT * FROM `characters` ORDER BY `level` DESC LIMIT 5")
-        return utils.extract_name(player_data)
 
-    def get_meso_ranking(self):
-        """Fetches the Top 5 players in terms of mesos
+        prepared_statement = f"SELECT * FROM `characters` ORDER BY `level` DESC LIMIT {number_of_players}" \
+            if show_gm else f"SELECT * FROM `characters` WHERE `gm` < 1 ORDER BY `level` DESC LIMIT {number_of_players}"
 
-        Uses Lazuli::get_db_all_hits to query, and utility.extract_name to process the data.
+        player_data = self.get_db_all_hits(prepared_statement)
+        return utils.extract_name_and_value(player_data, "level")
+
+    def get_meso_ranking(self, number_of_players=5, show_gm=False):
+        """Fetches the top ranking players in terms of mesos
+
+        Uses Lazuli::get_db_all_hits to query, and utility.extract_name_and_value to process the data.
+
+        Args:
+            show_gm: (optional): Add GMs (Game Masters) to the list of rankings
+            number_of_players (optional): Int, e.g. Top 5 Ranking (default), Top 10 Ranking, etc.
 
         Returns:
-            List of Strings, representing player names
+            List of Tuples, representing player names and their corresponding mesos
         """
-        player_data = self.get_db_all_hits("SELECT * FROM `characters` ORDER BY `meso` DESC LIMIT 5")
-        return utils.extract_name(player_data)
+        prepared_statement = f"SELECT * FROM `characters` ORDER BY `meso` DESC LIMIT {number_of_players}" \
+            if show_gm else f"SELECT * FROM `characters` WHERE `gm` < 1 ORDER BY `meso` DESC LIMIT {number_of_players}"
 
-    def get_fame_ranking(self):
-        """Fetches the Top 5 players in terms of fame
+        player_data = self.get_db_all_hits(prepared_statement)
+        return utils.extract_name_and_value(player_data, "meso")
 
-        Uses Lazuli::get_db_all_hits to query, and utility.extract_name to process the data.
+    def get_fame_ranking(self, number_of_players=5, show_gm=False):
+        """Fetches the top ranking players in terms of fame
+
+        Uses Lazuli::get_db_all_hits to query, and utility.extract_name_and_value to process the data.
+
+        Args:
+            show_gm: (optional): Add GMs (Game Masters) to the list of rankings
+            number_of_players (optional): Int, e.g. Top 5 Ranking (default), Top 10 Ranking, etc.
 
         Returns:
-            List of Strings, representing player names
+            List of Tuples, representing player names and their corresponding fame
         """
-        player_data = self.get_db_all_hits("SELECT * FROM `characters` ORDER BY `fame` DESC LIMIT 5")
-        return utils.extract_name(player_data)
+        prepared_statement = f"SELECT * FROM `characters` ORDER BY `fame` DESC LIMIT {number_of_players}" \
+            if show_gm else f"SELECT * FROM `characters` WHERE `gm` < 1 ORDER BY `fame` DESC LIMIT {number_of_players}"
 
-    def get_rebirth_ranking(self):
-        """Fetches the Top 5 players in terms of rebirths
+        player_data = self.get_db_all_hits(prepared_statement)
+        return utils.extract_name_and_value(player_data, "fame")
 
-        Uses Lazuli::get_db_all_hits to query, and utility.extract_name to process the data.
+    def get_rebirth_ranking(self, number_of_players=5, show_gm=False):
+        """Fetches the top ranking players in terms of rebirths
+
+        Uses Lazuli::get_db_all_hits to query, and utility.extract_name_and_value to process the data.
+
+        Args:
+            show_gm: (optional): Add GMs (Game Masters) to the list of rankings
+            number_of_players (optional): Int, e.g. Top 5 Ranking (default), Top 10 Ranking, etc.
 
         Returns:
-            List of Strings, representing player names
+            List of Tuples, representing player names and their corresponding rebirths
         """
-        player_data = self.get_db_all_hits("SELECT * FROM `characters` ORDER BY `reborns` DESC LIMIT 5")
-        return utils.extract_name(player_data)
+        prepared_statement = f"SELECT * FROM `characters` ORDER BY `reborns` DESC LIMIT {number_of_players}" \
+            if show_gm else f"SELECT * FROM `characters` WHERE `gm` < 1 ORDER BY `reborns` DESC LIMIT {number_of_players}"
 
-    def get_rebirth_ranking_by_job_id(self, job_id):
-        """Fetches the Top 5 players of a particular class (specific Job ID), in terms of rebirths
+        player_data = self.get_db_all_hits(prepared_statement)
+        return utils.extract_name_and_value(player_data, "reborns")
 
-        Uses Lazuli::get_db_all_hits to query, and utility.extract_name to process the data.
+    def get_rebirth_ranking_by_job_id(self, job_id, number_of_players=5, show_gm=False):
+        """Fetches the top ranking players of a particular class (specific Job ID), in terms of rebirths
+
+        Uses Lazuli::get_db_all_hits to query, and utility.extract_name_and_value to process the data.
+
+        Args:
+            show_gm: (optional): Add GMs (Game Masters) to the list of rankings
+            job_id: Int, representing specific Job ID to query
+            number_of_players (optional): Int, e.g. Top 5 Ranking (default), Top 10 Ranking, etc.
 
         Returns:
-            List of Strings, representing player names
+            List of Tuples, representing player names and their corresponding rebirths
         """
-        player_data = self.get_db_all_hits(f"SELECT * FROM `characters` WHERE `job`={job_id} ORDER BY `reborns` DESC LIMIT 5")
-        return utils.extract_name(player_data)
+        prepared_statement = f"SELECT * FROM `characters` WHERE `job`={job_id} ORDER BY `reborns`DESC LIMIT {number_of_players}" \
+            if show_gm else f"SELECT * FROM `characters` WHERE `job`={job_id} AND `gm` < 1 ORDER BY" \
+                             f"`reborns` DESC LIMIT {number_of_players}"
+
+        player_data = self.get_db_all_hits(prepared_statement)
+        return utils.extract_name_and_value(player_data, "reborns")
